/*
 *
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 *   
 */
package org.oasisopen.sca.test.x;

import org.oasisopen.sca.annotation.*;
import org.oasisopen.sca.test.y.ServiceComplex1;
import org.oasisopen.sca.test.z.ComplexClass;


/**
 * Java component implementation
 * 1 service with interface Service1
 * 0 references
 *
 * This service compares the classloaders for:
 * a) The class itself and the service interface class (expects them to be equal)
 * b) The class itself and the ComplexClass that is the parameter of the service operation (expects them to be different)
 */
@Service(ServiceComplex1.class)
public class serviceComplex1Impl implements ServiceComplex1 {
	
	@Property(required=true)
	public String serviceName = "service1";
	
	/**
	 * Operation which checks the 3 classloaders of:
	 * 1) this class
	 * 2) the service interface class
	 * 3) the input parameter class
	 * @return - a String containing a reponse meessage which depends on the relationships
	 * of the 3 classloaders
	 */
	public String operation1(ComplexClass input) {
		String msg1 = " Service interface classloader same as Impl class classloader";
		String msg2 = " ComplexClass classloader different from Impl class classloader";
		ClassLoader cl1 = this.getClass().getClassLoader();
		ClassLoader cl2 = ServiceComplex1.class.getClassLoader();
		ClassLoader cl3 = input.getClass().getClassLoader();
		if( cl1 != cl2 ) msg1 = " Service interface classloader not same as Impl class classloader";
		if( cl1 == cl3 ) msg2 = " ComplexClass classloader is the same as Impl class classloader";
		return serviceName + " operation1 invoked" + msg1 + msg2;
	}
	
	/**
	 * Operation which returns the hashcode of the classloader used to load this class
	 * @return
	 */
	public String operation2() {
		ClassLoader cl1 = this.getClass().getClassLoader();
		return String.valueOf( cl1.hashCode() );
	}

}
