/*
 *
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 *   
 */
package org.oasisopen.sca.test;

import org.oasisopen.sca.annotation.*;
import org.oasisopen.sca.test.Service1;


/**
 * Java component implementation with
 * 1 service with interface Service1
 * 1 reference "reference1" (1..1) with interface Service1NoRemotable, with @Remotable on the setter method parameter
 * reference gets called when service1 operation1 is invoked
 * 
 * The setter method has a parameter which is typed by an interface which does not have a @Remotable annotation
 */
@Service(Service1.class)
public class Service1NoRemotableRefImpl implements Service1 {
	
	private String serviceName = "service1";
	private Service1NoRemotable reference1 = null;

	public String operation1(String input) {
		String result = reference1.operation1(input);
		return serviceName + " operation1 invoked" + " " + result;
	}
	
	/**
	 * Setter for a property with the name "serviceName"
	 * @param aServiceName - the service name
	 */
	@Property
	public void setServiceName( String aServiceName ) {
		serviceName = aServiceName;
	}
	
	/**
	 * Setter for a reference with the name "reference1"
	 * @param aReference - the reference proxy
	 */
	@Reference
	public void setReference1( @Remotable Service1NoRemotable aReference ) {
		reference1 = aReference;
	}

}
